import requests

class ChargesAPI:
    def __init__(self, api_key, env="prd", api_version="v2"):
        self.api_key = api_key
        self.base_url = self._get_base_url(env, api_version)

    def _get_base_url(self, env, api_version):
        if env == "prd":
            return f'https://api.barte.com/{api_version}/charges'
        elif env == "sandbox":
            return f'https://sandbox-api.barte.com/{api_version}/charges'
        else:
            raise ValueError("Invalid environment specified")

    def list_by_uuid(self, charge_uuid):
        headers = {
            'X-Token-Api': self.api_key
        }
        url = f"{self.base_url}/{charge_uuid}"
        response = requests.get(url, headers=headers)
        return response.json()

    def list(self, **params):
        headers = {
            'X-Token-Api': self.api_key
        }
        response = requests.get(self.base_url, headers=headers, params=params)
        return response.json()



import requests

class ReportSellersAPI:
    def __init__(self, api_key):
        self.api_key = api_key
        self.base_url = 'https://api2.barte.com/function/report-sellers'

    def send_report_sellers(self, query_file, recipient_email, id_seller, report_name, days_ago):
        headers = {
            'x-api-key': self.api_key,
            'Content-Type': 'application/json'
        }
        payload = {
            'query_file': query_file,
            'recipient_email': recipient_email,
            'id_seller': id_seller,
            'report_name': report_name,
            'days_ago': days_ago
        }
        response = requests.post(self.base_url, headers=headers, json=payload)
        return response.json()



from .charges import ChargesAPI
from .reportsellers import ReportSellersAPI

class BarteSDK:
    def __init__(self, api_key, env="prd", api_version="v2"):
        self.api_key = api_key
        self.env = env
        self.api_version = api_version
        self.charges = ChargesAPI(api_key, env, api_version)
        self.reportsellers = ReportSellersAPI(api_key, env, api_version)
